RequirementAction

Struct RequirementAction 

pub struct RequirementAction<Priority, Input, Action> { /* private fields */ }

Implementations

Source

impl<Priority, Input, Action> RequirementAction<Priority, Input, Action>

pub fn priority(&self) -> &Priority

pub fn action(&self) -> &Action

Source

impl<State, Input, Action: IncitingAction<State, Input>> RequirementAction<Priority<State>, Input, Action>
where Action::Requirement: ActionRequirement<Priority<State>, Input>,

pub fn try_new( priority: Priority<State>, action: Action, ) -> Result<RequirementAction<Priority<State>, Input, Action>, TryNewRequirementActionError<Priority<State>, Action>>

If the current state has any inputs that fit the requirement, return Some, otherwise None.

pub fn select( self, value: Input, ) -> Result<Action::Resolved, RequirementActionSelectionError<Self, <<Action::Requirement as ActionRequirement<Priority<State>, Input>>::Filter as StateFilter<Priority<State>, Input>>::Error>>

Source

impl<State, Input, IncitingAction: IncitingActionInfo<State>, Action: StackAction<State, Input, IncitingAction>> RequirementAction<PriorityStack<State, IncitingAction>, Input, Action>
where Action::Requirement: ActionRequirement<PriorityStack<State, IncitingAction>, Input>,

pub fn try_new( priority: PriorityStack<State, IncitingAction>, action: Action, ) -> Result<RequirementAction<PriorityStack<State, IncitingAction>, Input, Action>, TryNewRequirementActionError<PriorityStack<State, IncitingAction>, Action>>

If the current state has any inputs that fit the requirement, return Some, otherwise None.

pub fn select( self, value: Input, ) -> Result<Action::Resolved, RequirementActionSelectionError<Self, <<Action::Requirement as ActionRequirement<PriorityStack<State, IncitingAction>, Input>>::Filter as StateFilter<PriorityStack<State, IncitingAction>, Input>>::Error>>